@@ -1,11 +1,13 @@
 from __future__ import annotations
 
+from pathlib import Path
 from typing import Union
 
 from pls.args import args
 from pls.data.getters import emoji_icons, nerd_icons
 from pls.enums.icon_type import IconType
 from pls.enums.node_type import NodeType
+from pls.fs.stats import get_node_type, get_permission_text, get_size, get_username
 from pls.models.node_spec import NodeSpec
 
 
@@ -17,9 +19,11 @@ class Node:
     Nodes are read from the file system directly using ``os.walk``.
     """
 
-    def __init__(self, name: str, node_type: NodeType):
+    def __init__(self, name: str, path: Path):
         self.name = name
-        self.node_type = node_type
+        self.path = path
+
+        self.stat = path.stat()
 
         self.specs: list[NodeSpec] = []  # matched later (see ``map_specs``)
 
@@ -37,6 +41,12 @@ class Node:
 
         return name
 
+    @property
+    def node_type(self) -> NodeType:
+        """whether the node is a file, folder, symlink, FIFO etc."""
+
+        return get_node_type(self.stat.st_mode)
+
     @property
     def ext(self) -> Union[str, None]:
         """the extension of the node, i.e. the portion after the last dot"""
@@ -115,21 +125,28 @@ class Node:
 
         if format_rules:
             left = f"[{' '.join(format_rules)}]"
-            right = f"[/{' '.join(format_rules[::-1])}]"
+            right = "[/]"
         else:
             left = right = ""
         return left, right
 
     @property
-    def table_row(self) -> list[str]:
-        """the list of cells when presenting the node as a row in a table"""
-
-        cells = [self.formatted_name]
-        if args.icon != IconType.NONE:
-            cells.insert(0, self.icon)
+    def table_row(self) -> dict[str, str]:
+        """the mapping of column names and value when tabulating the node"""
 
         left, right = self.format_pair
-        return [f"{left}{cell}{right}" for cell in cells]
+
+        cells = dict()
+        cells["name"] = f"{left}{self.formatted_name}{right}"
+        if args.icon != IconType.NONE:
+            cells["icon"] = f"{left}{self.icon}{right}"
+        if args.details:
+            cells["perms"] = get_permission_text(self.stat.st_mode)
+            cells["user"] = get_username(self.stat.st_uid)
+            if self.node_type == NodeType.FILE:
+                cells["size"] = get_size(self.stat.st_size)
+
+        return cells
 
     def spec_attr(self, attr: str) -> Union[str, int, None]:
         """
